#!/bin/bash

# $Id: $
# Copyright (c) 2013 NetApp, Inc.
# All rights reserved.

# Used as the shell for the diag user.
#
# Prevents remote command execution other than SCP.
# Unlike the maintenance user, SCP access is *not* limited to a chroot jail.

# Prevent err msgs from getopts. We only care about the -c option
OPTERR=0

# Get the command to execute (from the -c option)
# Note that ssh will pass a command to execute as the -c option when ssh invokes this shell.
# When scp is used from a remote machine, then the command passed starts with scp.
COMMAND=
while getopts "c:" opt; do
    case $opt in
        c ) COMMAND=$OPTARG
            ;;
    esac
done

if [ "$SHLVL" -eq 1 ] ; then
    # SHELL LEVEL will be 1 when we are a login shell
    # For example when logging in via ssh, the console, or 'su - diag'

    if [ -z "$COMMAND" ] ; then
        # If no command was specified, just startup an interactive shell
        exec /bin/bash --login "$@"
    elif [[ "$COMMAND" == *sftp-server ]]; then
        echo "SFTP is not allowed for the diag user.  Please use SFTP as the maintenance user." 1>&2
        exit 1
    else
        exec "$COMMAND"
    fi
else
    # SHELL LEVEL will be greater than 1 when we are not a login shell
    # For example when root does 'su diag'
    cd ~
    exec /bin/bash "$@"
fi

