#!/usr/bin/perl

# $Id:  $
# Copyright (c) 2013 Network Appliance, Inc.
# All rights reserved.

package Route;

use strict;

=head1 NAME

Route - Model of a route found within an interface stanza in the /etc/network/interface file.

=head1 DESCRIPTION

Route - Model of a route found within an interface stanza in the /etc/network/interface file.

For example:

        up route add -net 10.0.0.0/16 gw 10.0.0.1 dev eth0


=head1 SUBROUTINES

=over 4

=item B<new>

    Function   : construct a new Route object.
    Returns    : A new empty Route object.

=cut
sub new {
    my $self = {};
    $self->{TYPE} = undef;
    $self->{DESTINATION} = undef,
    $self->{GATEWAY} = undef,
    bless($self);
    return $self;
}

=item B<type>

    Function   : Get/Set the type of route (-net or -host)
    Parameters : new type

=cut
sub type {
    my $self = shift;
    if (@_) { $self->{TYPE} = shift }
    return $self->{TYPE};
}

=item B<destination>

    Function   : Get/Set the destination address of the route (e.g. 1.1.1.1 or 1.1.1.0/16)
    Parameters : new destination

=cut
sub destination {
    my $self = shift;
    if (@_) { $self->{DESTINATION} = shift }
    return $self->{DESTINATION};
}

=item B<gateway>

    Function   : Get/Set the gateway address of the route (e.g. 1.1.1.1)
    Parameters : new gateway

=cut
sub gateway {
    my $self = shift;
    if (@_) { $self->{GATEWAY} = shift }
    return $self->{GATEWAY};
}

=back

=cut

1; # so the require or use succeeds

