#!/bin/bash

# $Id:  $
# Copyright (c) 2013 NetApp, Inc.
# All rights reserved.

# Script to change the maintenance user's password.
# Meant to be run via a grub menu item with the linux kernel init= param.
# Will reboot upon completion.
# Assumes there is only one user in the maintenance group.

. /home/maint/scripts/commonfunctions.sh

echo

MAINTENANCE_USER=`members maintenance`

function sysrq_reboot {
    # This is the equivalent of alt+sysrq+B.
    # http://rackerhacker.com/2009/01/29/linux-emergency-reboot-or-shutdown-with-magic-commands/
    # http://en.wikipedia.org/wiki/Magic_SysRq_key

    # It will work in cases where the normal reboot commands don't work.
    # However, changes will not be saved to disk, so it will not work in place
    # of the normal reboot after changing the password, because the password
    # change would not be saved to disk.

    echo s > /proc/sysrq-trigger
    echo b > /proc/sysrq-trigger
    exit
}

function main() {

    if [[ "x$MAINTENANCE_USER" == "x" ]] ; then

        echo "The maintenance user does not exist!"

        echo
        anykey
        echo

        sysrq_reboot

    else

        echo "Specify a new password for '$MAINTENANCE_USER' at the prompts below."

        i=0
        while true ; do
            echo
            /usr/bin/chattr -i /etc/passwd /etc/shadow
            passwd "$MAINTENANCE_USER"
            /usr/bin/chattr +i /etc/passwd /etc/shadow
            result=$?
            if [[ "$result" -eq 0 ]] ; then
                # Log the event into /var/log/auth.log
                # The rsyslog daemon isn't running yet, so start it just for this purpose.
                /etc/init.d/rsyslog start > /dev/null            
                logger -p "auth.info" "maintenance user '$MAINTENANCE_USER' password changed"
                /etc/init.d/rsyslog stop > /dev/null
                break
            elif [[ "$i" -eq 2 ]] ; then
                echo
                echo "Password for '$MAINTENANCE_USER' not changed."
                break
            else
                echo
                echo "Try again."
            fi

            i=$[i+1]
        done

        echo
        echo "*** System will now reboot ***"
        anykey
        echo

      # This is needed due to issue in Debian 7 where sysvinit is not set up properly
      # when booted to a script environment from grub as we are when this script is
      # run to change the maintenance user password from the grub menu.
      # See: http://www.linuxquestions.org/questions/linux-newbie-8/i-got-a-error-flag-init-dev-initctl-no-such-file-219080/

        mkfifo /dev/initctl
        reboot -f

        # In case reboot fails
        sysrq_reboot
    fi
}

main "$@"
