#!/bin/bash
# Changes the NTP server to the host specified in the first argument
# Returns 0 on success, non-zero on failure.
# If the second argument is "--skip-refresh" then the ntp daemon is not restarted.
#
# Called by the OnCommand server and auto config scripts
#
# The auto-config scripts use --skip-refresh because they are invoked
# before the ntp daemon is initially started.

set -e

CONF_FILE=/etc/ntp.conf

if [[ $# -lt 1 || $# -gt 2 ]]; then
    echo "Usage: `basename $0` <ip address> [--skip-refresh]"
    exit 1
fi

SKIP_REFRESH=0
if [[ $# -eq 2 ]] ; then
    if [[ "$2" == "--skip-refresh" ]]; then
        SKIP_REFRESH=1
    else
        echo "Usage: `basename $0` <ip address> [--skip-refresh]"
        exit 1
    fi
fi

HOST=$1
if [[ $HOST =~ ([0-9]{1,3}\.){3}([0-9]){1,3} ]] || [[ $HOST =~ .*:.* ]]; then
    # We were given an IP already
    ADDR=$HOST
	if ! ping -c1 $ADDR > /dev/null 2>&1; then
	  echo "Host '$HOST' not found"
	  exit 1
	fi
else
    if ! host $HOST > /dev/null 2>&1; then
        echo "Host '$HOST' not found"
        exit 1
    fi
    ADDR=`host $HOST | grep -m1 'has address' | sed 's/^.* has address \(.*\)$/\1/'`
fi

# Change the IP on the following lines of /etc/ntp.conf:
# server 192.43.244.18 iburst
# restrict 192.43.244.18 nomodify notrap nopeer noquery
sudo sed --in-place=.`date "+%Y-%m-%d_%H:%M"` "/^server 98/ a server $HOST iburst" $CONF_FILE
sudo sed --in-place=.`date "+%Y-%m-%d_%H:%M"` "/^restrict 98.* nomodify notrap nopeer noquery/ a restrict $HOST nomodify notrap nopeer noquery" $CONF_FILE

if [[ $SKIP_REFRESH -eq 0 ]] ; then
    sudo service ntp restart > /dev/null 2>&1
fi
echo "NTP server added : $HOST"

