#!/bin/bash

# $Id:  $
# Copyright (c) 2013 NetApp, Inc.
# All rights reserved.

# Allows the maintenance user to gain a diagnostic shell.
#
# This script must be run as root on the vm console.
#
# Enforcement is as follows:
#     ownership:   root:root
#     permissions: -r-x------
#     The maintenance user is given sudo access to this script.

set -e

# Note that /home/maint/scripts/commonfunctions.sh
# needs to be owned by root and writable only by root for this to be secure
. /home/maint/scripts/commonfunctions.sh

onVmConsole || {
    echo "Diagnostic shell is only available when running on the virtual machine console." 1>&2
    TTY=`tty`
    logger -p "auth.warning" TTY=$TTY diag shell access denied
    exit 1
}

# If the diag user is expired, lock it instead. This achieves the same thing,
# but `su` displays a warning for an expired user whereas it does not for a
# locked user.
userExpired diag && {
    chattr -i /etc/passwd /etc/shadow
    usermod --lock --expiredate -1 diag
    chattr +i /etc/passwd /etc/shadow
}

logger -p "auth.notice" diag shell access granted

su -s /bin/bash - diag
