#!/bin/bash

# $Id$
# Copyright (c) 2015 Network Appliance, Inc.
# All rights reserved.

. /home/maint/scripts/commonfunctions.sh

jail_disk=/jail

# This script expands size of jail disk on appliance.
# Jail disk is "hard disk 4" as shown in vsphere client.


# Extend ext3 file system on the jail disk.
function extend_ext3_file_system () {
	# Check the sanity of ext3 file system.
	echo "Checking $1 ..."
	e2fsck -p -f $1 >&/dev/null
	if [ $? -ne 0 ] ;then
		echo "ext3 file system sanity check failed before disk expand"
		echo "exiting ...."
		exit 100
	fi

	# Resize ext3 file system.
	echo "Expanding file system..."
	resize2fs -p $1
	if [ $? -ne 0 ] ; then
		echo "resizing ext3 file system failed."
		echo "exiting ..."
	fi

	# Again check the sanity of ext3 file system
	echo "Re-checking $1 ..."
	e2fsck -p -f $1 >&/dev/null
	if [ $? -ne 0 ] ;then
		echo "ext3 file system sanity check failed after disk expand"
		echo "exiting ...."
		exit 100
	fi
}

# Extend jail partition
function extend_jail_partition () {
        jail_device="$1"

	part_start=`fdisk -l $jail_device | grep 'Linux' | awk '{print $2}'`

	echo
	# re-create the partition
	fdisk $jail_device <<EOF >&/dev/null
d
n
p
1
$part_start

w
EOF

        if [ $? -eq 0 ] ; then
                echo "Increased jail partition size to fit new space."
                return 0
        else
                echo "The jail disk size could not be increased."
                echo "Ensure that you increased the jail disk size from the vSphere Client"
                echo "before running this script."
                echo "Jail disk is \"Hard Disk 4\" as shown in the \"Edit Settings\""
                echo "section of your VM in the vSphere Client."
                return 1
        fi
	
}

# Extend jail disk.
function extend_jail_disk () {
        # Get old disk size
        oldSize=`df | grep ${jail_disk}$ | awk '{print $2}' | tr -d '\n'`

        # Get UUID for jail disk and get physical device for jail disk.
        jail_mapper_device=`cat /etc/fstab | grep "${jail_disk}"  | cut -d' ' -f1`
        #jail_device=`pvs | grep "/dev/sd" | awk '{print $1}' | tr -d '\n'`
        jail_device=`grep "${jail_disk}" /etc/mtab | cut -f1 -d' ' | sed s/[0-9]//`

        # Stop all the services which may use jail disk
        serverStartStop all stop
        echo
        if [[ $? -ne 0 ]]; then
                echo "The applications could not be stopped."
                echo" Exiting the process of increasing jail disk size..."
                exit 1
        fi
        
        # umount jail disk
        umount ${jail_disk}

        # Re-read the partition table to get new sizes.
        blockdev -q --rereadpt $jail_device
        sleep 2
        echo

        # extend the jail disk partition
        extend_jail_partition $jail_device
        ret=$?
        if [[ $ret -eq 0 ]]; then
            sleep 2
            # jail disk has ext3 file system.
            extend_ext3_file_system $jail_mapper_device
        fi
        sleep 5
        echo

        # mount jail disk
        mount ${jail_disk}

        if [[ $ret -ne 0 ]];then
            return 1
        fi

        # Get the new size and print a msg for user
        newSize=`df | grep ${jail_disk}$ | awk '{print $2}' | tr -d '\n'`

        # Start all the stopped services
        serverStartStop all start
        echo

        if [ $newSize -gt $oldSize ] ; then
                echo "The size of jail disk is increased from $oldSize MB to $newSize MB."
                return 0
        else
                echo "The jail disk size could not be increased."
                echo "Ensure that you increased the jail disk size from the vSphere Client"
                echo "before running this script."
                echo "Jail disk is \"Hard Disk 4\" as shown in the \"Edit Settings\""
                echo "section of your VM in the vSphere Client."
                return 1
        fi
}


# check to see if jail disk exist
df -kh ${jail_disk} >&/dev/null
if [ $? -eq 0 ] ; then
	# Go ahead
	echo
	echo "Before continuing with this option, ensure that you have increased the jail"
	echo "disk size from \"Edit Settings\" section of your VM in the vSphere Client."
	echo "If you have not increased the jail disk size, you can do so now and then"
	echo "type \"yes\" in the below prompt."
	echo "Jail disk is \"Hard Disk 4\" as shown in \"Edit Settings\""
	echo "section of your VM in the vSphere Client."
	echo
	echo
	echo
	echo "Increasing jail disk size will temporarily stop the applications."
	echo "After increasing jail disk size, applications will restart."
	echo


	read -r -p "Do you wish to continue? (y/n):" answer
	if [ "$answer" != "y" ]; then
		exit 1
	fi

	extend_jail_disk
else
	# Error out
	echo "mount point ${jail_disk} does not exist"
	exit 1
fi
