#!/bin/bash

# $Id: $
# Copyright (c) 2013 NetApp, Inc.
# All rights reserved.

# Checks/enables/disables SSH access.
#
# This script must be run as root. In order to change the ssh state,
# it must be run via the vm console.
#
# Enforcement is as follows:
#     ownership:   root:root
#     permissions: -r-x------
#     The maintenance user is given sudo access to this script.

set -e

# Note that /home/maint/scripts/commonfunctions.sh
# needs to be owned by root and writable only by root for this to be secure
. /home/maint/scripts/commonfunctions.sh

# Returns 0 if ssh is disabled.
function ssh_enabled_check() {
    /bin/ls /etc/rc?.d/S??ssh > /dev/null 2>&1 && {
        return 1 # enabled
    } || {
        return 0 # disabled
        }
}

function ssh_enable() {
    echo
    echo -n "Would you like to enable SSH access? (y/n) "
    read enableDiag
    if [[ $enableDiag = [yY] ]] ; then
        echo
        echo -n "Enabling SSH access... "
        /usr/sbin/update-rc.d ssh enable > /dev/null 2>&1 && {
            logger -p "auth.info" "ssh access enabled"
            serverStartStop ssh start && {
                echo "Done."
            } || {
                echo "SSH enabled but start failed"
                logger -p "auth.info" "ssh start failed"
            }
        } || {
            logger -p "auth.info" "failure enabling ssh access"
            echo "Failed."
        }
    fi
}

function ssh_disable() {
    echo
    echo -n "Would you like to disable SSH access? (y/n) "
    read disableDiag
    if [[ $disableDiag = [yY] ]] ; then
        echo
        echo -n "Disabling SSH access... "
        
        /usr/sbin/update-rc.d ssh disable > /dev/null 2>&1 && {
            logger -p "auth.info" "ssh access disabled"
            serverStartStop ssh stop && {
                echo "Done."
            } || {
                echo "SSH disabled but stop failed"
                logger -p "auth.info" "ssh stop failed"
            }
        } || {
            logger -p "auth.info" "failure disabling ssh access"
            echo "Failed."
        }
    fi
}


function main() {
    local rc=0

    ssh_enabled_check  || {
        rc=1
    }

    if [[ $# -eq 1 ]] ; then
        onVmConsole || {
            echo
            echo "SSH access can be toggled by accessing this prompt through the"
            echo "virtual machine console."
            exit $rc
        }
        
        case "$1" in
            "enable")
                    ssh_enable
                    ;;
            "disable")
                    ssh_disable
                    ;;
        esac
        rc=$(ssh_enabled_check)
    fi

    exit $rc
}

main "$@"
